@@ -8,6 +8,8 @@ use File::Basename;
 $FASTX::PE::VERSION = $FASTX::Reader::VERSION;
 #ABSTRACT: A Paired-End FASTQ files reader, based on FASTX::Reader.
 
+my $for_suffix_re = '(/1|_R?1)';
+my $rev_suffix_re = '(/2|_R?2)';
 
 
 sub new {
@@ -75,14 +77,14 @@ sub new {
           $rev =~s/$self->{tag1}/$self->{tag2}/;
           $rev = dirname($self->{basename}) . $rev;
         } else {
-          
+
           $rev =~s/_R1/_R2/;
           say STDERR "R2 not provided, autoguess (_R1/_R2): $rev" if ($self->{verbose});
           if ($rev eq basename($self->{filename}) ) {
               $rev =~s/_1\./_2./;
               say STDERR "R2 not provided for $self->{filename}, now autoguess (_1/_2): $rev" if ($self->{verbose});
           }
- 
+
           $rev = dirname($self->{filename}) . '/' . $rev;
         }
 
@@ -102,7 +104,7 @@ sub new {
       }
 
       $self->{R1}  = FASTX::Reader->new({ filename => "$self->{filename}"});
-      $self->{R2}  = FASTX::Reader->new({ filename => "$self->{rev}"}) 
+      $self->{R2}  = FASTX::Reader->new({ filename => "$self->{rev}"})
         if (not $self->{interleaved});
 
     }
@@ -129,18 +131,33 @@ sub getReads {
     $r2 = $self->{R2}->getRead();
   }
 
-  if (! defined $r1->{name} or !defined $r2->{name}) {
+  if (! defined $r1->{name} and !defined $r2->{name}) {
+    return undef;
+  } elsif (! defined $r1->{name} or !defined $r2->{name}) {
+    my $r = $r1->{name} // $r2->{name};
+    $self->{error} = "Premature termination, missing read mate for \"$r\"";
     return undef;
   }
 
+  my $name_1;
+  my $name_2;
+
   if ($self->{nocheck} != 1) {
-    if ($r1->{name} ne  $r2->{name}) {
+    $name_1 = $r1->{name};
+    $name_2 = $r2->{name};
+    $name_1 =~s/${for_suffix_re}$//;
+    $name_2 =~s/${rev_suffix_re}$//;
+    if ($name_1 ne $name_2) {
       confess("Read name different in PE:\n[$r1->{name}] !=\n[$r2->{name}]\n");
     }
+
+    if (not $r1->{qual} or  not $r2->{qual}) {
+      confess("Missing quality for one of the two reads ($name_1, $name_2)");
+    }
   }
 
 
-  $pe->{name} = $r1->{name};
+  $pe->{name} = $name_1 // $r1->{name};
   $pe->{seq1} = $r1->{seq};
   $pe->{qual1} = $r1->{qual};
 
@@ -183,7 +200,7 @@ FASTX::PE - A Paired-End FASTQ files reader, based on FASTX::Reader.
 
 =head1 VERSION
 
-version 0.87
+version 0.88
 
 =head1 SYNOPSIS
 
@@ -215,7 +232,7 @@ Initialize a new FASTX::Reader object passing 'B<filename>' argument for the fir
 and optionally 'B<rev>' for the second (otherwise can be guessed substituting 'R1' with 'R2' and
 '_1.' with '_2.')
 
-  my $pairend = FASTX::Reader->new({ 
+  my $pairend = FASTX::Reader->new({
       filename => "$file_R1",
       rev      => "$file_R2"
   });
@@ -243,7 +260,7 @@ The returned object has these attributes:
 
 header of the sequence (identifier)
 
-=item I<comment1> and I<comment2> 
+=item I<comment1> and I<comment2>
 
 any string after the first whitespace in the header, for the first and second paired read respectively.
 
@@ -251,7 +268,7 @@ any string after the first whitespace in the header, for the first and second pa
 
 DNA sequence for the first and the second pair, respectively
 
-=item I<qual1> and I<qual2> 
+=item I<qual1> and I<qual2>
 
 quality for the first and the second pair, respectively
 
